#!/bin/bash
# Check for Docker
if ! command -v docker &> /dev/null; then
    echo "Docker is required. Please install it first: https://docs.docker.com/get-docker/"
    exit 1
fi

# Check for DDEV
if ! command -v ddev &> /dev/null; then
    echo "DDEV is required. Install it with: brew install ddev/ddev/ddev (macOS/Linux) or see https://ddev.readthedocs.io/en/stable/"
    exit 1
fi

# Prompt user for project directory name
read -p "Enter the project directory name: " project_name

# Create directory, configure, and install Drupal
mkdir "$project_name" && cd "$project_name" || exit
echo 'Configuring ddev...'
ddev config --project-type=drupal --docroot=web --create-docroot
echo 'Starting ddev...'
ddev start
echo 'Creating drupal/recommended-project...'

ddev composer create drupal/recommended-project -y
#ddev composer create drupal/recommended-project --prefer-source -y

echo 'Fetching Drush...'
ddev composer require drush/drush
echo 'Installing Drupal...'
ddev drush site:install --account-name=admin --account-pass=admin -y
echo 'Fetching + Suite...'
ddev composer require drupal/plus_suite
echo 'Installing + Suite...'
ddev drush recipe ../recipes/plus_suite/
echo 'Clearing caches...'
ddev drush cr
echo 'Launching site...'
if command -v open &> /dev/null; then
    ddev drush uli | xargs open
else
    ddev launch
fi
